<template>
  <a-card :bordered="false">

    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form
        layout="inline"
        @keyup.enter.native="searchQuery"
      >
        <a-row :gutter="24">
          <a-col
            :xl="6"
            :lg="7"
            :md="8"
            :sm="24"
          >
            <a-form-item label="单据号">
              <a-input
                placeholder="请输入单据号"
                v-model="queryParam.scrapCode"
              ></a-input>
            </a-form-item>
          </a-col>
          <template v-if="toggleSearchStatus">
            <a-col
              :xl="6"
              :lg="7"
              :md="8"
              :sm="24"
            >
              <a-form-item label="备件名称">
                <a-input
                  placeholder="请输入备件名称"
                  v-model="queryParam.partName"
                ></a-input>
              </a-form-item>
            </a-col>

          </template>
          <a-col
            :xl="6"
            :lg="7"
            :md="8"
            :sm="24"
          >
            <span
              style="float: left;overflow: hidden;"
              class="table-page-search-submitButtons"
            >
              <a-button
                type="primary"
                @click="searchQuery"
                icon="search"
              >查询</a-button>
              <a-button
                type="primary"
                @click="searchReset"
                icon="reload"
                style="margin-left: 8px"
              >重置</a-button>
              <a
                @click="handleToggleSearch"
                style="margin-left: 8px"
              >
                {{ toggleSearchStatus ? '收起' : '展开' }}
                <a-icon :type="toggleSearchStatus ? 'up' : 'down'" />
              </a>
            </span>
          </a-col>

        </a-row>
      </a-form>
    </div>

    <!-- 操作按钮区域 -->
    <div class="table-operator">
      <a-button
        @click="handleAdd"
        type="primary"
        icon="plus"
      >新增</a-button>
      <!-- <a-button
        type="primary"
        icon="download"
        @click="handleExportXls('备品备件报废')"
      >导出</a-button>
      <a-upload
        name="file"
        :showUploadList="false"
        :multiple="false"
        :headers="tokenHeader"
        :action="importExcelUrl"
        @change="handleImportExcel"
      >
        <a-button
          type="primary"
          icon="import"
        >导入</a-button>
      </a-upload> -->
      <a-dropdown v-if="selectedRowKeys.length > 0">
        <a-menu slot="overlay">
          <a-menu-item
            key="1"
            @click="batchDel"
          ><a-icon type="delete" />删除</a-menu-item>
        </a-menu>
        <a-button style="margin-left: 8px"> 批量操作 <a-icon type="down" /></a-button>
      </a-dropdown>
    </div>

    <!-- table区域-begin -->
    <div>
      <div
        class="ant-alert ant-alert-info"
        style="margin-bottom: 16px;"
      >
        <i class="anticon anticon-info-circle ant-alert-icon"></i> 已选择 <a style="font-weight: 600">{{ selectedRowKeys.length }}</a>项
        <a
          style="margin-left: 24px"
          @click="onClearSelected"
        >清空</a>
      </div>

      <a-table
        ref="table"
        size="middle"
        bordered
        rowKey="id"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        class="j-table-force-nowrap"
        :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}"
        @change="handleTableChange"
      >

        <span
          slot="action"
          slot-scope="text, record"
        >
          <a
            v-show="record.scrapStatus === '1'"
            @click="handleEdit(record)"
          >编辑</a>

          <a-divider type="vertical" />
          <a
            v-show="record.scrapStatus === '1'"
            @click="handleConfirm(record)"
          >审核确认</a>

          <a-divider type="vertical" />
          <a-dropdown>
            <a
              v-show="record.scrapStatus === '1'"
              class="ant-dropdown-link"
            >更多 <a-icon type="down" /></a>
            <a-menu
              v-show="record.scrapStatus === '1'"
              slot="overlay"
            >
              <a-menu-item>
                <a-popconfirm
                  title="确定删除吗?"
                  @confirm="() => handleDelete(record.id)"
                >
                  <a>删除</a>
                </a-popconfirm>
              </a-menu-item>
            </a-menu>
          </a-dropdown>
        </span>

      </a-table>
    </div>
    <!-- table区域-end -->

    <!-- 表单区域 -->
    <eamSparePartScrap-modal
      ref="modalForm"
      @ok="modalFormOk"
    ></eamSparePartScrap-modal>
  </a-card>
</template>

<script>
import '@assets/less/TableExpand.less'
import EamSparePartScrapModal from './modules/EamSparePartScrap/EamSparePartScrapModal.vue'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import { deleteAction, getAction, postAction } from '@api/manage'

export default {
  name: "EamSparePartScrapList",
  mixins: [JeecgListMixin],
  components: {
    EamSparePartScrapModal
  },
  data() {
    return {
      description: '备品备件报废管理页面',
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: "center",
          customRender: function (t, r, index) {
            return parseInt(index) + 1;
          }
        },
        {
          title: '单据号',
          align: "center",
          dataIndex: 'scrapCode'
        },
        {
          title: '备件名称',
          align: "center",
          dataIndex: 'partName'
        },
        {
          title: '备件型号',
          align: "center",
          dataIndex: 'partModel'
        },
        {
          title: '报废原因',
          align: "center",
          dataIndex: 'scrapReason'
        },
        {
          title: '报废数量',
          align: "center",
          dataIndex: 'scrapNum'
        },
        {
          title: '申请人',
          align: "center",
          dataIndex: 'reportUser'
        },
        {
          title: '审核人',
          align: "center",
          dataIndex: 'approvalUser'
        },
        {
          title: '审核时间',
          align: "center",
          dataIndex: 'approvalTime'
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: "center",
          scopedSlots: { customRender: 'action' },
        }
      ],
      url: {
        list: "/eam/eamSparePartScrap/list",
        delete: "/eam/eamSparePartScrap/delete",
        deleteBatch: "/eam/eamSparePartScrap/deleteBatch",
        exportXlsUrl: "eam/eamSparePartScrap/exportXls",
        importExcelUrl: "eam/eamSparePartScrap/importExcel",
        confirm: "/eam/eamSparePartScrap/confirm",
      },
    }
  },
  computed: {
    importExcelUrl: function () {
      return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`;
    }
  },
  methods: {
    handleConfirm(record) {
      if (!this.url.confirm) {
        this.$message.error('请设置url.confirm属性!')
        return
      }
      var that = this
      this.$confirm({
        title: '备件报废确认',
        content: '确认备件报废吗?',
        onOk: function () {
          that.loading = true;
          postAction(that.url.confirm, record).then((res) => {
            if (res.success) {
              that.$message.success(res.message)
              that.loadData()
            } else {
              that.$message.warning(res.message)
            }
            that.loading = false
          }).finally(() => {
            that.loading = false;
          });
        }
      })
    },
  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>